Class: Google::Cloud::Iap::V1::AllowedDomainsSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/iap/v1/service.rb

Overview

Configuration for IAP allowed domains. Lets you to restrict access to an app and allow access to only the domains that you list.

Instance Attribute Summary collapse

Instance Attribute Details

#domains::Array<::String>

Returns Optional. List of trusted domains.

Returns:

  • (::Array<::String>)

    Optional. List of trusted domains.



375
376
377
378
# File 'proto_docs/google/cloud/iap/v1/service.rb', line 375

class AllowedDomainsSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable::Boolean

Returns Optional. Configuration for customers to opt in for the feature.

Returns:

  • (::Boolean)

    Optional. Configuration for customers to opt in for the feature.



375
376
377
378
# File 'proto_docs/google/cloud/iap/v1/service.rb', line 375

class AllowedDomainsSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end