Class: Google::Cloud::Iap::V1::ApplicationSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Iap::V1::ApplicationSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/iap/v1/service.rb
Overview
Wrapper over application specific settings for IAP.
Instance Attribute Summary collapse
-
#access_denied_page_settings ⇒ ::Google::Cloud::Iap::V1::AccessDeniedPageSettings
Optional.
-
#attribute_propagation_settings ⇒ ::Google::Cloud::Iap::V1::AttributePropagationSettings
Optional.
-
#cookie_domain ⇒ ::Google::Protobuf::StringValue
The Domain value to set for cookies generated by IAP.
-
#csm_settings ⇒ ::Google::Cloud::Iap::V1::CsmSettings
Optional.
Instance Attribute Details
#access_denied_page_settings ⇒ ::Google::Cloud::Iap::V1::AccessDeniedPageSettings
Returns Optional. Customization for Access Denied page.
394 395 396 397 |
# File 'proto_docs/google/cloud/iap/v1/service.rb', line 394 class ApplicationSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#attribute_propagation_settings ⇒ ::Google::Cloud::Iap::V1::AttributePropagationSettings
Returns Optional. Settings to configure attribute propagation.
394 395 396 397 |
# File 'proto_docs/google/cloud/iap/v1/service.rb', line 394 class ApplicationSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cookie_domain ⇒ ::Google::Protobuf::StringValue
Returns The Domain value to set for cookies generated by IAP. This value is not validated by the API, but will be ignored at runtime if invalid.
394 395 396 397 |
# File 'proto_docs/google/cloud/iap/v1/service.rb', line 394 class ApplicationSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#csm_settings ⇒ ::Google::Cloud::Iap::V1::CsmSettings
Returns Optional. Settings to configure IAP's behavior for a service mesh.
394 395 396 397 |
# File 'proto_docs/google/cloud/iap/v1/service.rb', line 394 class ApplicationSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |